==> ldap-account-manager_7.4.orig.tar.bz2: ldap-account-manager-7.4/templates/lib/extra/ckeditor/plugins/link/lang/oc.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'oc', {
	acccessKey: 'Tòca d\'accessibilitat',
	advanced: 'Avançat',
	advisoryContentType: 'Tipe de contengut (indicatiu)',
	advisoryTitle: 'Infobulla',
	anchor: {
		toolbar: 'Ancòra',
		menu: 'Modificar l\'ancòra',
		title: 'Proprietats de l\'ancòra',
		name: 'Nom de l\'ancòra',
		errorName: 'Entratz lo nom de l\'ancòra',
		remove: 'Suprimir l\'ancòra'
	},
	anchorId: 'Per ID d\'element',
	anchorName: 'Per nom d\'ancòra',
	charset: 'Encodatge de la ressorsa ligada',
	cssClasses: 'Classas d\'estil',
	download: 'Forçar lo telecargament',
	displayText: 'Afichar lo tèxte',
	emailAddress: 'Adreça electronica',
	emailBody: 'Còs del messatge',
	emailSubject: 'Subjècte del messatge',
	id: 'Id',
	info: 'Informacions sul ligam',
	langCode: 'Còdi de lenga',
	langDir: 'Sens d\'escritura',
	langDirLTR: 'Esquèrra a dreita (LTR)',
	langDirRTL: 'Dreita a esquèrra (RTL)',
	menu: 'Modificar lo ligam',
	name: 'Nom',
	noAnchors: '(Cap d\'ancòra pas disponibla dins aqueste document)',
	noEmail: 'Entratz l\'adreça electronica',
	noUrl: 'Entratz l\'URL del ligam',
	other: '<autre>',
	popupDependent: 'Dependenta (Netscape)',
	popupFeatures: 'Caracteristicas de la fenèstra sorgissenta',
	popupFullScreen: 'Ecran complet (IE)',
	popupLeft: 'A esquèrra',
	popupLocationBar: 'Barra d\'adreça',
	popupMenuBar: 'Barra de menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desfilament',
	popupStatusBar: 'Barra d\'estat',
	popupToolbar: 'Barra d\'aisinas',
	popupTop: 'Amont',
	rel: 'Relacion',
	selectAnchor: 'Seleccionar una ancòra',
	styles: 'Estil',
	tabIndex: 'Indici de tabulacion',
	target: 'Cibla',
	targetFrame: '<quadre>',
	targetFrameName: 'Nom del quadre afectat',
	targetPopup: '<fenèstra sorgissenta>',
	targetPopupName: 'Nom de la fenèstra sorgissenta',
	title: 'Ligam',
	toAnchor: 'Ancòra',
	toEmail: 'Corrièl',
	toUrl: 'URL',
	toolbar: 'Ligam',
	type: 'Tipe de ligam',
	unlink: 'Suprimir lo ligam',
	upload: 'Mandar'
} );

==> ldap-account-manager_8.3.orig.tar.bz2: ldap-account-manager-8.3/templates/lib/extra/ckeditor/plugins/link/lang/oc.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'oc', {
	acccessKey: 'Tòca d\'accessibilitat',
	advanced: 'Avançat',
	advisoryContentType: 'Tipe de contengut (indicatiu)',
	advisoryTitle: 'Infobulla',
	anchor: {
		toolbar: 'Ancòra',
		menu: 'Modificar l\'ancòra',
		title: 'Proprietats de l\'ancòra',
		name: 'Nom de l\'ancòra',
		errorName: 'Entratz lo nom de l\'ancòra',
		remove: 'Suprimir l\'ancòra'
	},
	anchorId: 'Per ID d\'element',
	anchorName: 'Per nom d\'ancòra',
	charset: 'Encodatge de la ressorsa ligada',
	cssClasses: 'Classas d\'estil',
	download: 'Forçar lo telecargament',
	displayText: 'Afichar lo tèxte',
	emailAddress: 'Adreça electronica',
	emailBody: 'Còs del messatge',
	emailSubject: 'Subjècte del messatge',
	id: 'Id',
	info: 'Informacions sul ligam',
	langCode: 'Còdi de lenga',
	langDir: 'Sens d\'escritura',
	langDirLTR: 'Esquèrra a dreita (LTR)',
	langDirRTL: 'Dreita a esquèrra (RTL)',
	menu: 'Modificar lo ligam',
	name: 'Nom',
	noAnchors: '(Cap d\'ancòra pas disponibla dins aqueste document)',
	noEmail: 'Entratz l\'adreça electronica',
	noUrl: 'Entratz l\'URL del ligam',
	noTel: 'Please type the phone number', // MISSING
	other: '<autre>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dependenta (Netscape)',
	popupFeatures: 'Caracteristicas de la fenèstra sorgissenta',
	popupFullScreen: 'Ecran complet (IE)',
	popupLeft: 'A esquèrra',
	popupLocationBar: 'Barra d\'adreça',
	popupMenuBar: 'Barra de menú',
	popupResizable: 'Redimensionable',
	popupScrollBars: 'Barras de desfilament',
	popupStatusBar: 'Barra d\'estat',
	popupToolbar: 'Barra d\'aisinas',
	popupTop: 'Amont',
	rel: 'Relacion',
	selectAnchor: 'Seleccionar una ancòra',
	styles: 'Estil',
	tabIndex: 'Indici de tabulacion',
	target: 'Cibla',
	targetFrame: '<quadre>',
	targetFrameName: 'Nom del quadre afectat',
	targetPopup: '<fenèstra sorgissenta>',
	targetPopupName: 'Nom de la fenèstra sorgissenta',
	title: 'Ligam',
	toAnchor: 'Ancòra',
	toEmail: 'Corrièl',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ligam',
	type: 'Tipe de ligam',
	unlink: 'Suprimir lo ligam',
	upload: 'Mandar'
} );
